diff artifacts/src/main/java/org/dive4elements/river/exports/process/Processor.java @ 7075:253d80af5b7f generator-refactoring

More Processor refactoring - Unify aandf aaf and bundle variable names to bundle - Factor out diagram inversion code - Add function with new signature to BedDiffYear and QOut processors
author Andre Heinecke <aheinecke@intevation.de>
date Fri, 20 Sep 2013 16:25:43 +0200
parents f9d5020af0af
children f0731aa7b735
line wrap: on
line diff
--- a/artifacts/src/main/java/org/dive4elements/river/exports/process/Processor.java	Fri Sep 20 15:44:39 2013 +0200
+++ b/artifacts/src/main/java/org/dive4elements/river/exports/process/Processor.java	Fri Sep 20 16:25:43 2013 +0200
@@ -39,13 +39,13 @@
      * Processes data to generate e.g. a chart.
      *
      * @param generator XYChartGenerator to add output on.
      * @param aandf     The artifact and facet
      * @param theme     The theme that contains styling information.
      * @param visible   The visibility of the curve.
      */
     public void doOut(
             DiagramGenerator generator,
-            ArtifactAndFacet aandf,
+            ArtifactAndFacet bundle,
             ThemeDocument    theme,
             boolean          visible);
 
@@ -53,7 +53,7 @@
      * Processes data to generate e.g. a chart.
      *
      * @param generator DiagramGenerator to add output on.
      * @param aandf     The artifact and facet
      * @param theme     The theme that contains styling information.
      * @param visible   The visibility of the curve.
      * @param index     The index of the curve
@@ -61,7 +61,7 @@
     @Deprecated
     public void doOut(
             XYChartGenerator generator,
-            ArtifactAndFacet aandf,
+            ArtifactAndFacet bundle,
             ThemeDocument    theme,
             boolean          visible,
             int              index);
@@ -39,13 +39,13 @@
      *
      * @param generator XYChartGenerator to add output on.
-     * @param aandf     The artifact and facet
+     * @param bundle     The artifact and facet
      * @param theme     The theme that contains styling information.
      * @param visible   The visibility of the curve.
@@ -53,7 +53,7 @@
      *
      * @param generator DiagramGenerator to add output on.
-     * @param aandf     The artifact and facet
+     * @param bundle     The artifact and facet
      * @param theme     The theme that contains styling information.
      * @param visible   The visibility of the curve.

http://dive4elements.wald.intevation.org